# Slide Layout

In TPPT, you can declaratively define slide layouts using type definitions.

## Defining Slide Layouts

Slide layout definitions are declarative.

Currently, only placeholder definitions are supported.
